@@ -11,11 +11,11 @@ def _config():
        cfg = json.load(fp)
     return cfg
 
-def load_data(file_name):
+def read_data(file_name):
     config = _config()
     return BytesIO(_get_object(config, config['bucket_name'], file_name)['Body'].read())
 
-def save_data(file_name, data):
+def write_data(file_name, data):
     config = _config()
     if isinstance(data, pd.DataFrame):
         data = data.to_csv(index=False).encode()
